#
# spec file for package inspektor-gadget
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           inspektor-gadget
Version:        0.38.1
Release:        1.1
Summary:        A eBPF tool and systems inspection framework
License:        Apache-2.0
URL:            https://github.com/inspektor-gadget/inspektor-gadget
Source:         inspektor-gadget-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.22
BuildRequires:  zsh
# /usr/bin/ig conflicts with igrep
Conflicts:      igrep

%description
The eBPF tool and systems inspection framework for Kubernetes, containers and
Linux hosts

Inspektor Gadget is a collection of tools (or gadgets) to debug and inspect
Kubernetes resources and applications. It manages the packaging, deployment and
execution of eBPF programs in a Kubernetes cluster, including many based on BCC
tools, as well as some developed specifically for use in Inspektor Gadget. It
automatically maps low-level kernel primitives to high-level Kubernetes
resources, making it easier and quicker to find the relevant information.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -a 1 -p 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/inspektor-gadget/inspektor-gadget/internal/version.version=%{version} \
   -X main.gadgetimage=ghcr.io/inspektor-gadget/inspektor-gadget:latest" \
   -tags withoutebpf \
   -o bin/kubectl-gadget \
   github.com/inspektor-gadget/inspektor-gadget/cmd/kubectl-gadget

go build \
   -mod=vendor \
   -buildmode=pie \
   -tags withoutebpf \
   -ldflags=" \
   -X github.com/inspektor-gadget/inspektor-gadget/internal/version.version=%{version} \
   -X main.gadgetimage=ghcr.io/inspektor-gadget/inspektor-gadget:latest" \
   -o bin/gadgetctl \
   github.com/inspektor-gadget/inspektor-gadget/cmd/gadgetctl

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/inspektor-gadget/inspektor-gadget/internal/version.version=%{version} \
   -X github.com/inspektor-gadget/inspektor-gadget/cmd/common/image.builderImage=ghcr.io/inspektor-gadget/ebpf-builder:latest" \
   -tags netgo \
   -o bin/ig \
   github.com/inspektor-gadget/inspektor-gadget/cmd/ig

%install
# Install the binary.
install -D -m 0755 bin/kubectl-gadget %{buildroot}/%{_bindir}/kubectl-gadget
install -D -m 0755 bin/gadgetctl %{buildroot}/%{_bindir}/gadgetctl
install -D -m 0755 bin/gadgetctl %{buildroot}/%{_bindir}/ig

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/gadgetctl completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/gadgetctl
%{buildroot}/%{_bindir}/kubectl-gadget completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/kubectl-gadget

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/gadgetctl completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/gadgetctl.fish
%{buildroot}/%{_bindir}/kubectl-gadget completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/kubectl-gadget.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/gadgetctl completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_gadgetctl
%{buildroot}/%{_bindir}/kubectl-gadget completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_kubectl-gadget

%files
%doc README.md
%license LICENSE
%{_bindir}/gadgetctl
%{_bindir}/ig
%{_bindir}/kubectl-gadget

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/gadgetctl
%{_datarootdir}/bash-completion/completions/kubectl-gadget

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/gadgetctl.fish
%{_datarootdir}/fish/vendor_completions.d/kubectl-gadget.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_gadgetctl
%{_datarootdir}/zsh/site-functions/_kubectl-gadget

%changelog
* Thu Mar 20 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.38.1:
  * Security Improvements
  - go: bump the golang-x group across 5 directories with 1
    update by @burak-ok in #4232
  - go: bump github.com/expr-lang/expr from 1.16.9 to 1.17.1 by
    @burak-ok in #4231
  - go: bump github.com/containerd/containerd by @burak-ok in
    [#4233]
  * Bug Fixes
  - oci: call saveIndexWithLock after importing gadget images by
    @burak-ok in #4229
* Wed Mar  5 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.38.0:
  https://github.com/inspektor-gadget/inspektor-gadget/releases/tag/v0.38.0
  * Some relevant changes for this version are:
  - Initial support for user stack traces by @alban in #4004
  - gadgets: add qdisc_latency tracer by @patrickpichler in #3659
  - trace_dns: TCP support w/o reassembly by @mqasimsarfraz in
    [#4088]
  - operators: localmanager: Use datasource to attach and detach
    con… by @eiffel-fl in #3957
  - The memory consumption for some gadgets were reduced
  * General Improvements
  - Find interface name wrt to namespace by @AdvH039 in #3913
  - trace_exec, trace_dns: remove dynamic allocations from wasm
    module by @alban in #3995
  - Display external api masks of fsnotify as strings by @AdvH039
    in #4012
  - go/wasm: Update to Tinygo 0.35.0 by @burak-ok in #4002
  - Add warning if gadget is run with a different IG version by
    @mauriciovasquezbernal in #4035
  - Allow printing IG debug logs when running unit tests by
    @blanquicet in #4036
  - gadgets/trace_dns: Use same namespace for client and server
    by @AdvH039 in #3967
  - Fix typo by @Okabe-Rintarou-0 in #4059
  - operators/ebpf: Do not create kstack map before by
    @mauriciovasquezbernal in #4062
  - trace_exec: reduce maps size by @dorser in #4058
  - pkg/gadget-service/api-helpers: Set default values for unset
    params by @blanquicet in #4050
  - pkg/gadget-context/run: Remove superfluous global params
    validation by @blanquicet in #4079
  - ebpf-builder.Dockerfile: workaround to install
    software-properties-common by @alban in #4084
  - Improve gadget version skew warning by @mauriciovasquezbernal
    in #4061
  - builtin trace exec: reduce map size by @dorser in #4091
  - oci: Error out when handling wrong image by
    @mauriciovasquezbernal in #4108
  - ustack: don't warn about processes on the host by @alban in
    [#4087]
  - fsnotify: reduce map size by @alban in #4076
  - all gadgets: path_max: reduce from 4096 to 512 characters by
    @alban in #4083
  - wasm: Remove malloc requirement for guest by
    @mauriciovasquezbernal in #4097
  - operators/wasm: Add function to get syscall ID from syscall
    name. by @eiffel-fl in #4129
  - container-collection: initial containers: better logs for
    inexistent pid by @alban in #4137
  - trace_capabilities: support for Linux < 6.1 by @alban in
    [#4103]
  - operators: wasm: Have getSyscallID() returns -1 on error. by
    @eiffel-fl in #4136
  - ebpf-builder.Dockerfile: remove workaround on
    software-properties-common by @alban in #4118
  - operators/env: introduce operator to create new fields from
    environment variables by @flyth in #4134
  - otel: allow overriding key/name by @flyth in #4147
  * Bug Fixes
  - fixed open event size by @afek854 in #3965
  - service-oci: Synchronize access to runGadget.Send by
    @mqasimsarfraz in #4003
  - fsnotify: fix CORE accesses on different kernel versions by
    @alban in #4046
  - limiter: Fix max-entries for multiple targets by @blanquicet
    in #4009
  * Documentation Improvements
  - Website fixes by @mauriciovasquezbernal in #3989
  - docs: Add part related to security improvements in release
    notes temp… by @eiffel-fl in #4001
  - gadgets/top_blockio/README.mdx: fix typo by @mapk0y in #4054
  - docs: pull-secret: more explanations by @alban in #4092
  - artifacthub: add missing description for
    profile_qdisc_latency by @alban in #4102
  - docs: fix ustack sample code by @flyth in #4139
  * Testing and Continue Integration
  - Make images configurable by @AdvH039 in #3954
  - [Tests]: Created Unit Test Coverage for templates.go in
    pkg/columns by @Dhiren-Mhatre in #3972
  - [Tests]: test for /pkg/utils/syscalls by @upsaurav12 in #3966
  - ci: Update unit test kernel versions by
    @mauriciovasquezbernal in #4005
  - fix: fix flaky TestPerf(#4008) by @Okabe-Rintarou-0 in #4014
  - [Tests]:Created Unit Test Coverage for setk8defaults.go in
    pkg/factory by @Dhiren-Mhatre in #3974
  - gadgets: Update url of ci-kernels by @mauriciovasquezbernal
    in #4051
  - chore: generate wasm operators test artifact before testing
    by @Okabe-Rintarou-0 in #4045
  - pkg/operators: Simplify perf buffer testing. by @eiffel-fl in
    [#4028]
  - tests: added unit test to fsnotify gadget by @4rivappa in
    [#3729]
  - [Tests]: Unit Test for pkg/utils/protocols by @upsaurav12 in
    [#4011]
  - [Tests] : Add unit tests for logger.go in pkg/logger by
    @Dhiren-Mhatre in #3988
  - ci: Run image-based gadgets on cloud providers too by
    @mauriciovasquezbernal in #4063
  - [test]:improve coverage for kallsysms.go in pkg/kallsyms by
    @Dhiren-Mhatre in #4042
  - unit test pkg/datasource/formatters/json by @upsaurav12 in
    [#4022]
  - ci: Mirror dockerhub images to our repo by
    @mauriciovasquezbernal in #4121
  - ci: Fix location of ci images by @mauriciovasquezbernal in
    [#4133]
  - ci: check links by @alban in #4124
  - snapshot_process: Increase timeout to fix test by
    @mauriciovasquezbernal in #4138
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.37.0:
  Some relevant changes for this version are:
  - trace_tcpconnect: Merge into trace_tcp by @burak-ok in #3720
  - trace exec gadgets: add support for execveat by @alban in
    [#3868]
  - tree-wide: deprecate built in gadgets by
    @mauriciovasquezbernal in #3931
  * General Improvements
  - Artifact Hub: Update gadgets version to v0.36.0 by
    @github-actions in #3855
  - trace exec gadgets: add exepath in case of failure by @alban
    in #3856
  - tree-wide: Bump golang to 1.23 by @mauriciovasquezbernal in
    [#3859]
  - ebpf: Do not use deprecated RewriteConstants function by
    @mauriciovasquezbernal in #3797
  - gadgets: trace_oomkill: Use gadget_process structure. by
    @eiffel-fl in #3828
  - Refactor LocalManger to be used from package level variable
    only by @Sefi4 in #3843
  - operators/wasm: Add support for array/hash of maps. by
    @eiffel-fl in #3815
  - operators/wasm: Add functions to get syscalls names and
    declarations. by @eiffel-fl in #3756
  - gadgets: Provide human readable representation of bytes by
    @KapilSareen in #3867
  - build: Make ebpf layer optional by @mauriciovasquezbernal in
    [#3819]
  - gha: Disable stale bot by @mauriciovasquezbernal in #3866
  - Adds dev and inode number field in trace_exec by @KapilSareen
    in #3848
  - wasmapi: Bump available map to reflect cilium/ebpf 0.17.1. by
    @eiffel-fl in #3889
  - Adding fupper layer field for trace_exec image-based gadget
    by @Sefi4 in #3869
  - provide human representation of time by @KapilSareen in #3883
  - Add runc path of kubeadm cluster running on Debian12 with
    upstream cri-o by @cjl7 in #3739
  - Adding support for non unix:// prefix in socket paths by
    @amitschendel in #3798
  - container-hook: improve logging by @alban in #3864
  - Feature/add ptid to exec by @afek854 in #3870
  - kubectl-gadget: return client version when server not
    available by @devusb in #3909
  - operators/wasm: Add functions to interact with perf buffer.
    by @eiffel-fl in #3725
  - trace_tcp: Add fd (updated from Burak's #3850) by @alban in
    [#3916]
  - sockerenricher: only insert socket if it doesn't exist by
    @mqasimsarfraz in #3923
  - filter: Allow escaping commas by @mqasimsarfraz in #3907
  - Add additional dns information by @AdvH039 in #3874
  - tree-wide: Updates to go.mod files by @mauriciovasquezbernal
    in #3920
  - WASM: Release handles by @burak-ok in #3702
  - pkg/oci: Use a file lock to avoid concurrency issues by
    @mauriciovasquezbernal in #3842
  - wasm: add kallsymsSymbolExists by @alban in #3871
  * Security Improvements
  - gha: Observe GitHub good practice by @mauriciovasquezbernal
    in #3924
  - trace_tcp: add option to see only failed connections by
    @alban in #3928
  - Added node name to slim pod by @afek854 in #3953
  - kallsyms: implement just in time lookups without allocations
    by @alban in #3932
  * Bug Fixes
  - fixes DNS trace formatting by @KapilSareen in #3845
  - oci-service: Fix closing logic by @mauriciovasquezbernal in
    [#3865]
  - gadgetctl/kubectl-gadget: fixes crash when running attach
    right after run by @KapilSareen in #3852
  - operators/wasm: Check map type is supported in operation
    functions. by @eiffel-fl in #3881
  - oci: Fix image list crash by @mauriciovasquezbernal in #3908
  - pkg/oci: small fixes by @mauriciovasquezbernal in #3919
  - pkg/oci: Log errors as warning instead of debug when listing
    images. by @eiffel-fl in #3917
  - pkg/operators: Fix getSyscallDeclaration() import in
    badguest. by @eiffel-fl in #3930
  - Fix reading loginuid/sessionid in kernels without
    CONFIG_AUDIT by @Sefi4 in #3961
  - perf/ring buffer: Continue reading in case of errors by
    @mqasimsarfraz in #3955
  - ebpf/tracer: Report lost samples by @mqasimsarfraz in #3956
  * Documentation Improvements
  - docs: multiple filters by @mqasimsarfraz in #3899
  - ADOPTERS.md: Fixes contributing link for retina.sh. by
    @eiffel-fl in #3947
  - examples/instance-manifest: Add examples by @mqasimsarfraz in
    [#3849]
  - docs/api: Improve Golang API documentation by
    @mauriciovasquezbernal in #3948
  * Testing and Continue Integration
  - trace_exec: test for execveat by @alban in #3882
  - CI: static analysis of ig binary size by @KapilSareen in
    [#3915]
  - ci: report memory usage of ig with pprof by @KapilSareen in
    [#3925]
* Tue Jan 21 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.36.1:
  * oci-service: Fix closing logic
  * fixes DNS trace formatting
  * trace exec gadgets: add support for execveat
  * gadgetctl/kubectl-gadget: fixes crash when running attach right
    after run
* Tue Jan  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.36.0:
  * Some relevant changes for this version are:
  - introduce support for otel-logs by @flyth in #3697
  - trace_dns: add fields cwd & exepath (--paths) by @alban in
    [#3817]
  - gadgets: Uniform filtering by @mauriciovasquezbernal in #3648
  * General Improvements
  - CODEOWNERS: Update following latest changes in the code by
    @mauriciovasquezbernal in #3649
  - Artifact Hub: Update gadgets version to v0.35.0 by
    @github-actions in #3735
  - Update ADOPTERS.md by @mayasingh17 in #3727
  - expose SocketPath in k8s.go by @matthyx in #3730
  - tree-wide: Fix clang-format target and apply it by
    @mauriciovasquezbernal in #3753
  - Export filter operator by @Sefi4 in #3774
  - deploy/charts: allow configuring otel-metrics by
    @mqasimsarfraz in #3684
  - treewide: Format eBPF code using clang-format-18. by
    @eiffel-fl in #3809
  - Update ADOPTERS.md by @mayasingh17 in #3785
  - ebpf-builder: Update to clang-18 and provide clang-format by
    @mauriciovasquezbernal in #3825
  - cilium/ebpf: Update to v0.17.1 by @burak-ok in #3829
  - pkg/gadgets: dns: Update generated bpf2go files with
    cilium/ebpf v0.1… by @eiffel-fl in #3834
  - Align datasource enrichment by @Sefi4 in #3668
  - feat(kubectl-gadget): disallow instances with same name by
    @KapilSareen in #3839
  - trace exec: add 'file' field for scripts by @alban in #3818
  - Update entrypoint logic for gadget-container by @KapilSareen
    in #3811
  - export the whole RuntimeConfig in K8sClient by @matthyx in
    [#3816]
  - tree-wide: Remove usage of multierr by @mauriciovasquezbernal
    in #3841
  - oci: remote manifest file by @mqasimsarfraz in #3807
  - wasm/testdata: Use in-tree ig to build the images by
    @burak-ok in #3757
  - pkg: Rework error message to cope with code scanning alerts.
    by @eiffel-fl in #3847
  * Bug Fixes
  - ig-k8s: Fix server version message by @mauriciovasquezbernal
    in #3743
  - ig-k8s: Fix fix server version message by
    @mauriciovasquezbernal in #3752
  - operators/bpf: Fix perf ring buffer fallback logic by
    @mauriciovasquezbernal in #3633
  - dns: don't send full packet to userspace by @alban in #3806
  - (built-in)/trace/dns: Fix logic for percpu array map by
    @mauriciovasquezbernal in #3830
  * Testing and Continue Integration
  - ci: Add "Signed-off-by" to commit bumping artifacthub-pkg.yml
    files. by @eiffel-fl in #3736
  - dependabot: Add group for containers dependency by
    @mauriciovasquezbernal in #3738
  - dependabot: Use directories key by @mauriciovasquezbernal in
    [#3766]
  - ci/check-artifacthub-tags: Add permissions by @mqasimsarfraz
    in #3765
  - tests: Increase timeout for snapshotter tests by
    @mauriciovasquezbernal in #3760
  - Alias ebpftypes.Process as Process in utils package by
    @MeherRushi in #3764
  - ci: Enable workflow_dispatch by @mauriciovasquezbernal in
    [#3792]
* Tue Jan  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.35.0:
  * Some relevant changes for this version are:
  - Add maps functions to WASM by @eiffel-fl in #3596
  - gadgets/deadlock: add deadlock detection using cycles in
    mutex wait di-graph by @Snehil-Shah in #3532
  - New gadget: fdpass by @alban in #3672
  * General Improvements
  - feat: enhance version command output to json format by
    @Priyansurout in #3651
  - gadgets: Standardize common information by
    @mauriciovasquezbernal in #3506
  - Use ContainerPid method in example by @ninadingole in #3674
  - datasource: refactor SetRequested to Unreference & add to
    WASM API by @Snehil-Shah in #3657
  - field: add AddTags method to fieldAccessor and corresponding
    WASM API by @Snehil-Shah in #3652
  - uprobe,container-hook: add coherence check on file sizes by
    @alban in #3701
  - Added TID for execsnoop & open by @afek854 in #3658
  - Adding exepath field for trace_exec image-based gadget by
    @Sefi4 in #3695
  - tools/monitoring: Use otel-metrics exporter by @mqasimsarfraz
    in #3639
  - gadgets/deadlock: handle dead processes and add pid based
    filtering by @Snehil-Shah in #3717
  - operators/wasm: Add WASM function to create and close maps.
    by @eiffel-fl in #3713
  - container-hook: additional coherence checks by @alban in
    [#3724]
  - exec args: support up to 256 bytes per arg by @alban in #3726
  * Bug Fixes
  - trace_tcpconnect: Fix missing src and dst ip and port on
    error by @burak-ok in #3517
  - gadgets/tcpdrop: Fix mount ns filtering by @mqasimsarfraz in
    [#3632]
  - oci-handler: fix annotate param merge with prior config by
    @flyth in #3696
  - tools/monitoring: Remove the old dashboard by @mqasimsarfraz
    in #3715
  - Remove runcfanotify package by @alban in #3699
  * Documentation Improvements
  - Add ADOPTERS.md file by @alban in #3671
  - Readme: Update the declarative config line in the features
    list by @blixtra in #3685
  - Readme: Update section to only show recent videos by @blixtra
    in #3686
  * Testing and Continue Integration
  - ci: test image gadgets on different kernel versions by
    @mastersans in #3631
  - ci: added workflow to verify artifacthub tags by @4rivappa in
    [#3703]
* Mon Nov  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.34.0:
  Welcome to the v0.34.0 release of Inspektor Gadget.
  A selection of relevant changes are:
  - introduce headless mode for k8s by @flyth in #3587
  - otel-metrics: add support for named metric exporters and
    otlp-grpc by @flyth in #3588
  - operators: kubeipresolver for image-based gadgets by
    @mqasimsarfraz in #3586
  * General Improvements
  - operators/localmanager: Do not print warning if the runtime
    is not found by @mauriciovasquezbernal in #3540
  - operators: Fix location of enriched fields by
    @mauriciovasquezbernal in #3523
  - formatters: enrich proto field to include protocol name in L4
    endpoints by @Snehil-Shah in #3329
  - pkg/operators/otel-metrics: Hide render datasource from
    gadget users by @blanquicet in #3566
  - operators/formatters: Hide endpoint subfield proto by
    @mqasimsarfraz in #3599
  - go.mod: update cilium/ebpf with some memory optimization by
    @alban in #3595
  - cmd/image: Print build logs when using verbose mode by
    @mauriciovasquezbernal in #3598
  - pkg/operators/wasm/testdata: Update go version by @blanquicet
    in #3615
  - go.mod: update cilium/ebpf with more memory optimization by
    @alban in #3616
  - gadgets: Automatically add annotations based on the field
    types by @mauriciovasquezbernal in #3600
  - Move authfile and pull-secret to GlobalParams and update
    documentation by @Priyansurout in #3622
  - Container enrichment: add container PID by @alban in #3501
  - operators/kubeipresolver: Improve how endpoint is displayed
    by @mqasimsarfraz in #3611
  - Makefile: make the 'docker build' command configurable by
    @alban in #3621
  - oci: Expose pull-secret param only when running on k8s by
    @mauriciovasquezbernal in #3628
  - feat: Accepting IPv4 and IPv6 parameters as command line
    input arguments by @MeherRushi in #3575
  - operators/cli: Improve logic to print header by
    @mauriciovasquezbernal in #3641
  - tools/monitoring: fix typo by @vbatts in #3646
  - Makefile: Introduce target to run go mod tidy by
    @mauriciovasquezbernal in #3653
  * Bug Fixes
  - operators/ebpf: Fix race condition with wasm operator by
    @mauriciovasquezbernal in #3542
  - fix: json decoder out of sync error for gadgetrunner by
    @mastersans in #3573
  - operators/ebpf: Fix map iterators waiting logic by
    @mauriciovasquezbernal in #3654
  * Documentation Improvements
  - readme: Add link for CDS 2024 by @mqasimsarfraz in #3553
  - docs: Remove increasing sidebar_position from docs/gadgets by
    @burak-ok in #3574
  - docs/gadget-devel: How to use Data, DataArray and Packet in
    WASM API by @blanquicet in #3610
  - Add gadget user documentation for exporting metrics to
    Prometheus by @flyth in #3539
  - docs: Update l4endpoint formatting by @mqasimsarfraz in #3630
  - docs: audit-seccomp: update runc requirement by @alban in
    [#3642]
  - docs/gadget-devel/gadget-intro: Specify support of Map
    Iterators by @blanquicet in #3593
  * Testing and Continue Integration
  - Revert "ci: Use -j$(nproc) with gadgets Makefile." by
    @mauriciovasquezbernal in #3555
  - ci: Fix permission for release workflow by @mqasimsarfraz in
    [#3558]
  - Unit testing Image Based Gadgets by @mastersans in #3502
  - cri: move tests to separate package by @alban in #3585
  - tests: implement inner field tests by @mauriciovasquezbernal
    in #3572
  - build: fix dockerignore file by @alban in #3620
  - test: Added tests for gadgets/snapshot_socket by @btwshivam
    in #3283
  - operators/wasm: add test for emitting packets from new
    datasource by @Snehil-Shah in #3613
  - tests: Disable TestTraceNetwork on containerd by @burak-ok in
    [#3669]
* Fri Oct 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.33.0:
  * Welcome to the v0.33.0 release of Inspektor Gadget. The most
    relevant changes for this version are:
  - introduce GadgetInstanceManager to run gadgets headless by
    @flyth in #2960
  - Add profile_tcprtt by @eiffel-fl in #3452
  - gadgets: add gadget to trace mutex locks/unlocks by
    @Snehil-Shah in #3503
  - Add top_blockio by @burak-ok in #3273
  - gadgets: Port trace_fsslower to image-based by
    @mauriciovasquezbernal in #3463
  - cmd/common: allow to specify gadget runtime configuration
    using "-f" by @flyth in #3515
  * General Improvements
  - gadgets/top_file: Provide full file path by @MeherRushi in
    [#3347]
  - clioperator: Add support for adding / removing fields with
  - -fields by @h4l0gen in #3284
  - Add inspect subcommand to image by @eiffel-fl in #3382
  - gadgets: Update readme by @mauriciovasquezbernal in #3428
  - pkg/oci: Rename ListGadgetImages() to GetGadgetImages(). by
    @eiffel-fl in #3442
  - pkg/operators/otel-metrics: don't automatically apply metrics
    type based on role tag by @flyth in #3447
  - pkg/datasource: Use FullName to look for fields in config by
    @blanquicet in #3448
  - treewide: Bump go to 1.22.7. by @eiffel-fl in #3458
  - fsnotify: add new fields by @alban in #3438
  - Add a second map to get pods and svcs by IP without GetCmp by
    @matthyx in #3446
  - pkg: Add safeset package. by @eiffel-fl in #3472
  - trace-dns: use new fields from socket enricher by @alban in
    [#2684]
  - oci: Set artifactType in all cases by @mauriciovasquezbernal
    in #3469
  - socket enricher: warning in case of incompatibility by @alban
    in #3479
  - metadata: Clean up parameters handling by
    @mauriciovasquezbernal in #3490
  - cmd/build: Reduce duplicate code by @mauriciovasquezbernal in
    [#3498]
  - wasm: Add parameters handling to wasm by
    @mauriciovasquezbernal in #3449
  - pkg/operators/oci-handler: Support set annotations at runtime
    by @blanquicet in #3468
  - wasm: Add support for setting config by
    @mauriciovasquezbernal in #3475
  - gadgets: Rework the makefile to add better parallelism. by
    @eiffel-fl in #2987
  - feat: add verifier debug output when running faulty ebpf
    gadget by @patrickpichler in #3529
  - operators/kubeipresolver: Improve memory consumption by
    @mauriciovasquezbernal in #3530
  * Bug Fixes
  - operators/ebpf: Fix crash when spec doesn't contain types by
    @mauriciovasquezbernal in #3450
  - gadgets: Fix headless test by @mauriciovasquezbernal in #3519
  * Documentation Improvements
  - docs: add operator documentation by @mauriciovasquezbernal in
    [#3406]
  - docs/gadget-devel/building: Clarify that sudo needs to be run
    with -E by @mauriciovasquezbernal in #3435
  - docs/operators: remove links from diagram by
    @mauriciovasquezbernal in #3437
  - docs: Distinguish between ig and kubectl-gadget in kernel
    filtering by @blanquicet in #3423
  - docs: Improve trace_dns guide by @mqasimsarfraz in #3429
  - docs/specs/operators: Point to latest docs in pkg.go.dev by
    @blanquicet in #3440
  - docs: Extend documentation on allowed-gadgets. by @eiffel-fl
    in #3473
  - docs: Fix broken link for cosign container signing process.
    by @eiffel-fl in #3482
  - docs: Fix operators instance params by @mqasimsarfraz in
    [#3495]
  - docs: Use constants to point to correct versions in docs by
    @mauriciovasquezbernal in #3496
  - docs: Fixes for hello-world-gadget-wasm by @mqasimsarfraz in
    [#3512]
  - docs: Improve trace_oomkill guide by @mqasimsarfraz in #3493
  - gadgets/README.mdx: Update sidebar_position after adding
    top_blockio by @burak-ok in #3520
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.32.0:
  In this release, we focused on improving our documentation to
  ease people using and writing their own gadgets.
  We also added a new gadget to trace the calls to inotify() and
  fanotify().
  * General Improvements
  - tools: Remove check-readme. by @eiffel-fl in #3299
  - container-collection: Add OwnerKind and OwnerName to
    K8sEnrichment by @burak-ok in #3319
  - Post-release: update gadgets version to v0.31.0 by @alban in
    [#3339]
  - columns: add support for displaying event data in Hex format
    by @Snehil-Shah in #3307
  - example/Dockerfile: Use JSON args to prevent unintended
    behavior related to OS signals by @burak-ok in #3346
  - image build: allow alternative tinygo by @alban in #3348
  - datasource: Fix order for K8S.NODE by @mqasimsarfraz in #3323
  - gadgetctl/kubectl-gadget: Ensure sorting after combining data
    from all targets by @blanquicet in #3326
  - ig: Add optional further K8s enrichment (Ownertype and
    Ownername in this PR) by @burak-ok in #3360
  - New gadget: fsnotify by @alban in #3218
  - Add mechanism to disable pulling image-based gadgets by
    @eiffel-fl in #3369
  - pkg/operators/cli: Improve log level for errors and avoid
    blocking other ds when one fails by @blanquicet in #3413
  - pkg/datasource/columns: Default MaxWith attribute based on
    field type (For int and bool) by @blanquicet in #3414
  * Bug Fixes
  - pkg/gadgets: Fix tree output for snapshot process. by
    @eiffel-fl in #3315
  - image/build: Fix wasm compilation by @mauriciovasquezbernal
    in #3341
  - pkg/datasource: Hide enriched timestamp column by default by
    @blanquicet in #3378
  - cmd: Handle --apparmor-profile to work better on k8s 1.30 and
    higher. by @eiffel-fl in #3377
  - Switch to gopacket/gopacket by @mauriciovasquezbernal in
    [#3386]
  - charts: Fix config map volume by @mauriciovasquezbernal in
    [#3389]
  - columns template: add max size on some fields by @alban in
    [#3401]
  - pkg/operators: Add limiter by @blanquicet in #3327
  * Documentation Improvements
  - docs/gadget-devel/metadata: Improve description of
    datasources by @blanquicet in #3316
  - Document security related options for ig daemon by @eiffel-fl
    in #3322
  - Add link to v0.31.0 post in README by @blixtra in #3328
  - gadgets/top_tcp: fix typo in date by @alban in #3337
  - docs: Fix broken links by @mauriciovasquezbernal in #3300
  - docs: Fix more broken links by @mauriciovasquezbernal in
    [#3340]
  - docs/legacy: Update the sort_by list by @burak-ok in #3345
  - docs: Rename CONTRIBUTING.md by @mqasimsarfraz in #3349
  - treewide: Bump golang to 1.22.5. by @eiffel-fl in #3317
  - docs: Use GitHub instead of elixir by @mauriciovasquezbernal
    in #3359
  * Testing and Continue Integration
  - feat(test): added test for gadgets/trace_tcpconnect by
    @mastersans in #3258
  - snapshot_process: Sleep before starting the gadget by
    @burak-ok in #3338
  - gha: Remove unneeded strategy on workflow file by
    @andoriyaprashant in #3302
  - feat(test): added test for gadgets/trace_tcpretrans by
    @mastersans in #3294
  - ci: Automatically update website on push by
    @mauriciovasquezbernal in #3342
  - ci: Add check for gadget guides by @mqasimsarfraz in #3367
  - gadgets/readmes: update all gadgets documentation by @alban
    in #3358
  - docs: Add missing symlink to render gadget documentation by
    @mauriciovasquezbernal in #3364
  - docs/op: Add UidGidResolver documentation by @burak-ok in
    [#3324]
  - gadgets: update sourceURL and documentationURL by @alban in
    [#3376]
  - docs: add diagrams for running modes by @alban in #3219
  - docs: Add missing columns.hex annotation by
    @mauriciovasquezbernal in #3384
  - docs: Add Detailed Guide for Filtering in User Space by
    @andoriyaprashant in #3402
  - dependabot: Fix groups by @mauriciovasquezbernal in #3415
  - docs/spec/oci: Fix broken link by @blanquicet in #3422
  - docs: Add some links by @mauriciovasquezbernal in #3420
  - docs: fsnotify: replace handmade diagram by mermaid diagram
    by @alban in #3421
  - added change in docs by @836hardik-agrawal in #3425
* Tue Aug  6 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.31.0:
  With this release, we announce the general availability of
  image-based Gadgets (they aren't experimental anymore #3261) .
  The documentation is available here. Stay tuned at the
  inspektor-gadget.io website as we'll publish some blog posts with
  more information about this release.
  * General Improvements
  - trace_exec: remove unused variable uid by @i-Pear in #3100
  - GetCgroupID: read cgroup paths under host cgroup namespace by
    @alban in #3085
  - Artifact Hub: Update gadgets version to v0.30.0 by
    @github-actions in #3103
  - gadgets/trace_oomkill: Utilize new testing framework by
    @burak-ok in #3084
  - prometheus: Use different name for metrics config by
    @mqasimsarfraz in #3109
  - cmd/kubectl-gadget: Set k8s flags for runtime after parsing
    by @mqasimsarfraz in #3104
  - trace_tcpconnect: Add retcode by @burak-ok in #3069
  - artifacthub: use field 'digest' instead of 'createdAt' for
    reindexing by @alban in #3105
  - pkg/gadgets/run/types: Test string equality rather than
    contain to de… by @eiffel-fl in #3114
  - cmd: Support a Configuration File by @mqasimsarfraz in #2831
  - add otel-metrics operator for image-based gadgets by @flyth
    in #2900
  - gadgets: Add trace_bind by @mauriciovasquezbernal in #3067
  - kubeinvcache: Create the cachedmaps on demand by @burak-ok in
    [#2815]
  - Update google.golang.org/grpc to v1.65.0 by
    @mauriciovasquezbernal in #3122
  - minikube.mk: switch minikube to use kubernetes v1.30.0 by
    @alban in #3128
  - [2nd attempt] container-collection: add process metadata
    enricher by @alban in #3091
  - Improve endpoints formatter by @mauriciovasquezbernal in
    [#3076]
  - gadgets/trace_bind: Fix trace_bind after formatters rework by
    @mauriciovasquezbernal in #3129
  - gadgettracermanager: Set environment to Kubernetes by
    @mqasimsarfraz in #3136
  - Adding docker runtime image digest enrichment for running
    containers by @Sefi4 in #3139
  - pkg/gadgets: Use tp_btf for top block-io. by @eiffel-fl in
    [#3146]
  - Dockerfiles: Use JSON for linter ENTRYPOINT. by @eiffel-fl in
    [#3160]
  - tree-wide: Freeze perf event array map by
    @mauriciovasquezbernal in #3151
  - pkg/oci: Add option to only run image-based gadgets from
    specific registries by @eiffel-fl in #3145
  - config: Add support for ig-k8s by @mqasimsarfraz in #3150
  - gadgets: Forward config to datasources by
    @mauriciovasquezbernal in #3149
  - pkg/operators/ebpf: Allow passing field configuration as
    annotations by @blanquicet in #3171
  - gadgets: Add audit seccomp by @mauriciovasquezbernal in #3170
  - Use global param for public key by @eiffel-fl in #3158
  - Adding pcomm field by @Sefi4 in #3142
  - Update metadata validation and generation by
    @mauriciovasquezbernal in #3164
  - metadata: Fix leftovers after review by
    @mauriciovasquezbernal in #3183
  - gadget-context: make sure cancel() is called on gadgetContext
    by @flyth in #3186
  - cmd/common/config: Remove line to initialize oci operator. by
    @eiffel-fl in #3189
  - gadgets: Uniform common info they provide by
    @mauriciovasquezbernal in #3169
  - pkg/operators/ebpf: make enum handling deterministic by
    @flyth in #3190
  - gadgets: Provide human readable version of error codes by
    @burak-ok in #3148
  - config/params: add support for string slices by @eiffel-fl in
    [#3192]
  - Add support to specify several public keys by @eiffel-fl in
    [#3174]
  - image-based gadgets: introduce map iterators by @flyth in
    [#3182]
  - ebpf-builder.Dockerfile: Use uppercase keyword by @burak-ok
    in #3205
  - container-hook: simplify sys_exit_execve logic by @alban in
    [#3138]
  - tree-wide: Pin base images on Dockerfiles by
    @mauriciovasquezbernal in #3198
  - container-hook: Remove unused bpf objects by
    @mauriciovasquezbernal in #3206
  - Dockerfiles: Fix typo for kubectl-gadget.Dockerfile hash. by
    @eiffel-fl in #3215
  - treewide: Remove unused verify-gadgets flag and adapt CI jobs
    to dependabot by @eiffel-fl in #3216
  - treewide: Fix usage of empty public keys. by @eiffel-fl in
    [#3226]
  - treewide: Add back --verify-gadgets. by @eiffel-fl in #3227
  - Use global parameters for --allowed-digests and
  - -allowed-registries by @eiffel-fl in #3181
  - gadgets: Update top_file to use map iterators instead of
    toppers by @blanquicet in #3207
  - Adding cwd field to trace_exec image-based gadget by @Sefi4
    in #3157
  - UidGidResolver: Make it usable in image based gadgets by
    @burak-ok in #3200
  - Improve insecure registries support by @mauriciovasquezbernal
    in #3252
  - ig/gadgetctl: add TLS support by @flyth in #2848
  - treewide: Replace allowed-digests and allowed-registries by
    allowed-gadgets by @eiffel-fl in #3251
  - gadgets: Add top_tcp as image based gadget by @burak-ok in
    [#3259]
  - Finish porting trace dns to image-based gadget by
    @mauriciovasquezbernal in #3093
  - pkg/operators: Add combiner by @blanquicet in #3068
  - image-based gadgets: add support for profiler gadgets by
    @flyth in #3253
  - tree-wide: Mark image-based gadgets as non experimental by
    @mauriciovasquezbernal in #3261
  * Bug Fixes
  - Makefile: Fix how ig-debug version is set. by @eiffel-fl in
    [#3108]
  - pkg/gadgets: Fix tracepoint for top block-io. by @eiffel-fl
    in #3272
  - pkg/datasource: Use FullName to add field. by @eiffel-fl in
    [#3271]
  - pkg/datasource: Use FullName instead of Name. by @eiffel-fl
    in #3293
  * Documentation Improvements
  - Update README.md for all image-based gadgets by @alban in
    [#3102]
  - docs: Add a link to verify instructions when ig is downloaded
    from release by @eiffel-fl in #3147
  - docs: point to the installation instructions on the IG
    website instead of the TOC on the repo by @flyth in #3173
  - docs: Rework structure and few improvements by
    @mauriciovasquezbernal in #3279
  - quick-start.md: run.md -> run.mdx by @burak-ok in #3297
  - README: Fix broken links by @mauriciovasquezbernal in #3298
  * Testing and Continue Integration
  - gadgets/Makefile: Report failing tests again by @burak-ok in
    [#3116]
  - gadgets: Test endpoints too by @mauriciovasquezbernal in
    [#3130]
  - gadgets/trace_capabilities: Add test by @burak-ok in #3115
  - ci: Report summaries for gadgets tests by
    @mauriciovasquezbernal in #3152
  - ci: Update instructions to create ARO cluster by
    @mauriciovasquezbernal in #3119
  - tests: Remove run top test and helpers for this by
    @mauriciovasquezbernal in #3161
  - gadgets: Test on containerd too by @mauriciovasquezbernal in
    [#3172]
  - CI: README: Add OpenSSF scorecard badge by @illume in #3098
  - ci: Pin Github Actions by @mauriciovasquezbernal in #3191
  - ci: Limit token permissions by @mauriciovasquezbernal in
    [#3197]
  - ci: Pin go install command to hash by @mauriciovasquezbernal
    in #3199
  - pkg/testing/ig: Support more than one flag on IG_FLAGS env
    variable by @blanquicet in #3220
  - ci: Verify eBPF builder image only if cosign secrets were
    set. by @eiffel-fl in #3217
  - ci: Remove documentation-checks from release needs. by
    @eiffel-fl in #3296
* Wed Jul  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.30.0:
  * ci: Set DOCKER_BUILD_NO_SUMMARY.
  * gadgets/trace_capabilities: Add special check for exec-family
    syscalls
  * gadgets: Add trace_capabilities
  * gadgets/trace_tcpdrop: Add kernel stack field
  * pkg/operators/ebpf: Support kernel stack map
  * pkg/oci: Add new options to restrain execution by digest.
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * gadgets: update README.md
  * gadgets/Makefile: add readme target
  * gadgets/trace_exec: Add tests
  * testing: Add helper to sleep
  * treewide: Remove unneeded systemd workaround.
  * ci: Use eastus2 for AKS
  * go: bump github.com/moby/moby
  * go: bump github.com/docker/cli
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * test/images: Test that export command is deterministic
  * build: Allow reproducible builds
  * kubemanager: Check ParamAllNamespaces in PreStart too
  * datasource: Return error on New()
  * go: bump github.com/moby/moby
  * go: bump github.com/docker/cli
  * ci: Remove ARO from release needs.
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * gadgets/snapshot_process: Port test to use new testing
    framework
  * pkg/testing/match: Add unittests
  * testing: Consolidate match logic in pkg/testing/match
  * CI: Use multinode cluster for testing gadgets on kubernetes
  * trace_mount: Add call column and flag decoding
  * docs: Remove mouting /run for ig.
  * pkg/container-utils: Preprend HOST_ROOT to
    /run/cri-dockerd.sock.
  * cmd/ig: Preprend host.HostRoot to runtime socket path.
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * docs: Add instruction to verify ebpf-builder image.
  * ci: Verify eBPF builder image before building gadgets.
  * Revert "container-collection: add process metadata enricher"
  * gadgets/trace_exec: Update metadata.
  * ci: bump docker/build-push-action from 5 to 6
  * ci: bump aquasecurity/trivy-action from 0.22.0 to 0.23.0
  * add sort operator import to ig and gadgettracermanager binaries
  * pkg/datasource: add @flyth as code owner
  * pkg/datasource: improve subscription handling
  * Fix codeowners
  * trace_tcp{drop,retrans}: Use bitfields for flags
  * ebpf/formatters: Support formatting bitfields
  * trace_open: Add missing fields
  * gadgets/test: Run tests even if wasm module exists
  * ig/build: Always pull builder-image if latest tag is used
  * tests: Disable TestTraceNetwork on cri-o
  * gadgets/trace_sni: Port test to use new testing framework
  * pkg/operators/sort: add unit tests
  * add sort operator
  * pkg/datasource: add Swap() method to DataArray
  * gadgets/ports: Convert to host endianess inside the gadget
  * go: bump github.com/containers/image/v5 from 5.31.0 to 5.31.1
  * go: bump github.com/tetratelabs/wazero from 1.7.1 to 1.7.3
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * gadgets/trace_exec: Add wasm module to handle args field
  * docs: Add guide to use wasm from a gadget
  * docs/reference: Add wasm reference docs
  * wasm: Add test to check consts are in sync
  * operators/wasm: Add tests
  * operators: Add wasm operator
  * image/build: Use correct Inspektor Gadget code in in-tree
    gadgets
  * gadgets: Port trace_tcp_test to gadgets
  * pkg/container-hook: Check container PID bound before converting
    it.
  * ci: bump actions/{download,upload}-artifact from 3 to 4
  * formatters: Avoid changing name of the field
  * operators/ebpf: Rename converters to formatters
  * ci: Use westeurope for AKS.
  * container-hook: delete old entries and marks after timeout
  * container-hook: use a single fanotify to watch pid files
  * integration/kubectl-gadget: Add an option to skip image
    verification
  * gadgets/test: Add an option skip image verification
  * ci: Skip signing ig-k8s image/gadget images on fork
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * go: bump github.com/miekg/dns from 1.1.59 to 1.1.61 in
    /tools/dnstester
  * execsnoop: add parent upper layer
  * gadgets/signal: Add test using the new framework.
  * integration/Command: Enhance error messages for kill
  * pkg/oci: Remove undeeded authOpts for getSigningInformation().
  * container-collection: add process metadata enricher
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * gadgets/trace_mount: Implement test using new framework
  * tests: Remove duplicated test
  * testing/containers: Add support for privileged mode
  * gadgets/trace_open: Improve tests
  * gadgets/trace_exec: drop uid filter on sys_exit_execve
  * pkg/gadgets/trace_exec: drop uid filter on sys_exit_execve
  * pkg/gadgets/capabilities: Fix pid field
  * container-hook: add new test
  * pkg/gadgets/capabilities: fix pid and tgid fields
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * ci: Use --format to retrieve image digest instead of grep and
    awk.
  * go: bump github.com/spf13/cobra from 1.8.0 to 1.8.1
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * go: bump github.com/docker/docker
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * ci: Sign helper images.
  * go: bump github.com/moby/moby
  * ci: Sign ig container image.
  * ci: Add action to sign container image.
  * go: bump the k8s group with 8 updates
  * uprobetracer: use secureopen to avoid TOCTOU issues
  * New pkg: secureopen: open files in containers
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * go: bump google.golang.org/protobuf from 1.34.1 to 1.34.2
  * Align k8s json and columns name
  * trace exec: extract fixup for execve as a common header
  * fields: Mark fields hidden based on attributes
  * ci: bump aquasecurity/trivy-action from 0.21.0 to 0.22.0
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * go: bump sigs.k8s.io/controller-runtime from 0.18.3 to 0.18.4
  * go: bump github.com/docker/{cli,docker} and
    github.com/moby/moby
  * go: bump github.com/containerd/containerd from 1.7.17 to 1.7.18
  * go: bump the golang-x group with 3 updates
  * go: bump github.com/containers/common from 0.59.0 to 0.59.1
  * Updating trace_open test to support testing in k8s and adding
    ci job for testing with k8s
  * adding helper functions for testing with k8s
  * gadgets/trace_exec: extract fixup for execve as a common header
  * go: bump github.com/spf13/viper from 1.18.2 to 1.19.0
  * go: bump github.com/mdlayher/socket from 0.4.1 to 0.5.1 in
    /examples
  * Artifact Hub: Update gadgets version to v0.29.0
  * container-collection: Don't rely on k8s.io/kubernetes/pkg/...
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * implementing container factory interface for k8s
  * updating field names: pod and container
* Mon Jun  3 2024 opensuse_buildservice@ojkastl.de
- update to version 0.29.0:
  * Welcome to the v0.29.0 release of Inspektor Gadget. The most
    relevant changes for this version are:
  - API: Support running gadgets from files and memory by
    @mauriciovasquezbernal in #2853
  - gadgets: Add trace_lsm by @i-Pear in #2827
  - gadgets: Add trace_ssl by @i-Pear in #2745
  - add filter operator by @flyth in #2805
  * General Improvements
  - Improve "CStrings" handling by @mauriciovasquezbernal in
    [#2797]
  - UserGroupCache: Move OnceValue to global scope by @burak-ok
    in #2809
  - kubernetes: cgroupfs: mount read-only by @alban in #2685
  - datasources: Add Bool accessors by @mauriciovasquezbernal in
    [#2796]
  - gadgets/trace_malloc: support more memory operations by
    @i-Pear in #2748
  - datasources: Add missing setters, allocate memory and add
    tests by @mauriciovasquezbernal in #2823
  - trace_dns: convert domain to dot notation (without wasm) by
    @alban in #2845
  - pkg/datasource: remove dependency on pkg/gadgets by @flyth in
    [#2850]
  - pkg/operators/ebpf: Avoid adding netns field to snapshot
    process by @blanquicet in #2838
  - snapshotters: Support sending and JSON-printing output as an
    array by @blanquicet in #2709
  - profile/block-io: use core type matches relocations by @alban
    in #2542
  - Add support for more iterators: task_file, ksym by @alban in
    [#2839]
  - minikube: Upgrade to v1.33.1 by @mqasimsarfraz in #2841
  - datasource: Allow setting smaller static strings by
    @mauriciovasquezbernal in #2832
  - sockets-map.h: remove most defines from socket enricher
    header by @alban in #2846
  - local/kube manager operators: Print warning for multiple
    net/mnt ns fields by @blanquicet in #2877
  - Revert "gadgets/trace_dns: add empty wasm module" by
    @mauriciovasquezbernal in #2886
  - cmd: Add JSON output to image list command. by @eiffel-fl in
    [#2885]
  - cmd/image/build: Add progress bar when pulling builder image
    by @mauriciovasquezbernal in #2888
  - charts: Set container filesystem as read only. by @eiffel-fl
    in #2442
  - pkg/{runcfanotify, container-hook}: Refactor code to use
    notify package. by @eiffel-fl in #2766
  - clean up operator initialization code by @flyth in #2901
  - Auto detect container runtime socket path by @dorser in #2794
  - Updates to dependabot by @mauriciovasquezbernal in #2915
  - pkg/operators/formatters: Add syscall formatter by @i-Pear in
    [#2913]
  - dependabot: Group gomod updates by dependency by
    @mauriciovasquezbernal in #2916
  - dependabot: Disable updating indirect dependencies by
    @mauriciovasquezbernal in #2955
  * Bug Fixes
  - oci-handler: Fix typo in error message by @mqasimsarfraz in
    [#2806]
  - kubectl-gadget: Multiple fixes around skipInfo logic by
    @mauriciovasquezbernal in #2774
  - trace/network: Close Operators after closing the tracer by
    @burak-ok in #2814
  - container-hook: fix sys_exit_execve from thread by @alban in
    [#2804]
  - oci: Fail is start image operator fails by
    @mauriciovasquezbernal in #2828
  - trace exec builtin gadget: fix memory usage by @alban in
    [#2840]
  - pkg/operators/simple: fix onStop() callback being called if
    only onStart is set by @flyth in #2851
  - version: Fix server version for ig-k8s by @mqasimsarfraz in
    [#2852]
  - trace_dns: fix padding by @alban in #2860
  - pkg/gadgets: Update comment about mntns_filter.h location by
    @blanquicet in #2866
  - localmanager: Avoid crashing if container collection isn't
    available by @mauriciovasquezbernal in #2874
  - pkg/operators: Fix tracing host events for mount namespace ID
    attache… by @eiffel-fl in #2879
  - Add runc symlink for rancher rke2 by @matthyx in #2764
  - Remove usage of go workspaces by @mauriciovasquezbernal in
    [#2914]
  - oci: Return error if op.Prepare() fails by
    @mauriciovasquezbernal in #2947
  * Documentation Improvements
  - Artifact Hub: Update gadgets version to v0.28.0 by
    @github-actions in #2808
  - Artifact Hub: Update gadgets version to v0.28.1 by
    @github-actions in #2861
  - Implement image-based gadgets examples by
    @mauriciovasquezbernal in #2753
  - docs: Add installation steps for helm charts by
    @mqasimsarfraz in #2878
  - docs/hello-world-gadget: Add missing --verify-image=false by
    @mauriciovasquezbernal in #2887
  - docs: Add documentation on how to sign image-based gadgets.
    by @eiffel-fl in #2894
  - docs: Use relative link to point to verification
    documentation. by @eiffel-fl in #2895
  - docs: Add initial wasm design doc by @mauriciovasquezbernal
    in #2896
  * Testing and Continue Integration
  - ci: Do not run cloud-cleanup on fork by @mqasimsarfraz in
    [#2807]
  - ci: Shifting deploy and undeploy logic for IG to actions by
    @pawarpranav83 in #2833
  - tests: Add tests for image export and import by
    @mauriciovasquezbernal in #2906
* Mon Jun  3 2024 opensuse_buildservice@ojkastl.de
- update to version 0.28.1:
  This is a Bugfix release which includes the following fixes:
  * container-hook: fix sys_exit_execve from thread by @alban in
    [#2804]
  * trace exec builtin gadget: fix memory usage by @alban in #2840
  * version: Fix server version for ig-k8s by @mqasimsarfraz in
    [#2852]
* Mon Jun  3 2024 opensuse_buildservice@ojkastl.de
- update to version 0.28.0:
  Welcome to the v0.28.0 release of Inspektor Gadget. The most
  relevant changes for this version are:
  * pkg/uprobetracer: add support for USDT tracepoints by @i-Pear
    in #2655
  * cmd: Verifying container image if policy controller is present.
    by @eiffel-fl in #2703
  * operators/ebpf: Support associate programs (iterators) to
    snapshotters by @blanquicet in #2637
  * Bump Go version to 1.22.0 by @burak-ok in #2744
  * Remove bpftrace by @eiffel-fl in #2757
  General Improvements
  * gadget-context: Don't add op instance's params if op is not
    requested by @blanquicet in #2667
  * pkg/uprobetracer: use kfilefields to identify inodes by @i-Pear
    in #2669
  * artifacthub-pkg.yml: update gadget versions to new release by
    @alban in #2679
  * re-add support for jsonpretty + yaml to image based gadgets by
    @flyth in #2652
  * trace/open: Compute error and file descriptor fields on eBPF
    code by @blanquicet in #2687
  * rename methods/structs/interfaces from Gadget... to
    BuiltInGadget... by @flyth in #2559
  * pkg/datasource: Don't use sync.Pool for data by @blanquicet in
    [#2708]
  * Cleanup custom-columns CLI flag by @shivaabhishek07 in #2465
  * cmd: Add --seccomp-profile to specify seccomp profile to apply
    to Inspektor Gadget by @eiffel-fl in #2710
  * treewide: remove run gadget by @flyth in #2673
  * add version skew warning by @mauriciovasquezbernal in #2718
  * run: Remove dead code by @mauriciovasquezbernal in #2740
  * cmd: Do not truncate output when listing image-based gadgets.
    by @eiffel-fl in #2743
  * tests.mk: Update kube-apiserver to 1.30.0 by @burak-ok in #2750
  * oci: Remove dead code by @mauriciovasquezbernal in #2754
  * Sign image based gadgets by @eiffel-fl in #2678
  * image/build: Implement option to keep built file by
    @mauriciovasquezbernal in #2738
  * pkg/uprobetracer: support LSM trace points by @i-Pear in #2747
  * trace/{dns,sni}: Split NewTracer() logic by @amirmalka in #2768
  * Verify image based gadget by @eiffel-fl in #2707
  * Add signal formatter by @mauriciovasquezbernal in #2630
  * gadget-service: Improve address validation by
    @mauriciovasquezbernal in #2780
  * cmd: Implement image import and export commands by
    @mauriciovasquezbernal in #2779
  * columns/filter: Add support for time.Duration by @mqasimsarfraz
    in #2791
  * trace exec: Add user and group field by @burak-ok in #2751
  * image-based gadgets: Implement btfgen support by
    @mauriciovasquezbernal in #2598
  Bug Fixes
  * charts: Add '/host/var' to volumeMounts by @mqasimsarfraz in
    [#2664]
  * image based gadgets: fix hostNetwork info by @flyth in #2674
  * image based gadgets: return error if no valid gadget layers are
    found by @flyth in #2691
  * resolve symlinks in runtime path by @matthyx in #2656
  * fix: re-add timeout for image-based gadgets by @flyth in #2713
  * ebpf: Remove trailing garbage when reading sample from perf
    event array by @mauriciovasquezbernal in #2720
  * KubeInventoryCache: Keep old pods/svcs in a cached for
    enrichment by @burak-ok in #2659
  * cmd: Require experimental flag for run command. by
    @mauriciovasquezbernal in #2778
  * fix gRPC timeout for image-based gadgets on GetGadgetInfo() by
    @flyth in #2712
  * pkg/oci: Use Singleton for getLocalOciStore by @burak-ok in
    [#2803]
  Documentation Improvements
  * docs/devel: Update hello world gadget guide by @blanquicet in
    [#2668]
  * docs: Document how to verify container image at runtime using
    policy-controller by @eiffel-fl in #2675
  * docs: Fix instructions to verify container image by
    @mauriciovasquezbernal in #2711
  * install-kubernetes.md: Fix and update table of contents by
    @burak-ok in #2749
  * examples: Move gadgets to builtin-gadgets by
    @mauriciovasquezbernal in #2769
  Testing and Continuous Integration
  * release: automatically update artifact hub version by @alban in
    [#2681]
  * integration: Separate and simplify container-related stuff by
    @blanquicet in #2666
  * ci: Add wait to ensure GKE clusters are deleted by
    @mqasimsarfraz in #2682
  * ci/lint: Skip package cache by @burak-ok in #2694
  * Avoid repeated code on inspektor-gadget and kubectl-gadget
    integration tests by @pawarpranav83 in #2450
  * ci: Check that metadata file is updated to
    build-and-push-gadgets by @mauriciovasquezbernal in #2702
  * Testing package for image-based gadgets by @pawarpranav83 in
    [#2607]
  * ci: Always build helper images on main and release branches by
    @mauriciovasquezbernal in #2737
  * integration: Add timestamp to Run/Start/Stop by @burak-ok in
    [#2661]
  * gadgets/trace_open/test: Verify container name and ID by
    @blanquicet in #2759
  * ci: Add workflow to clean eks resources by @burak-ok in #2686
  * test-integration-eks: Fix missing quotes + define explicit
    timeformat by @burak-ok in #2777
  * eks-cleanup: Don't error when stack can't be deleted by
    @burak-ok in #2784
  * TestRunTraceOOMKill: Add sleep after starting ig/kubectl-gadget
    by @burak-ok in #2785
  * integration: Logging timestamp before calling step.Stop by
    @burak-ok in #2790
  * tools: Rewrite check-readme in go by @mauriciovasquezbernal in
    [#2786]
* Thu Apr 25 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package inspektor-gadget: eBPF tool and systems inspection
  framework for Kubernetes, containers and Linux hosts
